import 'package:equatable/equatable.dart';
import 'package:flutter/material.dart';
import 'package:hydrated_bloc/hydrated_bloc.dart';

import 'package:stopmotion/config/default_activity_settings.dart';
import 'package:stopmotion/models/settings/settings_activity.dart';

part 'settings_activity_state.dart';

class ActivitySettingsCubit extends HydratedCubit<ActivitySettingsState> {
  ActivitySettingsCubit()
      : super(ActivitySettingsState(settings: ActivitySettings.createDefault()));

  void setValues({
    String? movieType,
  }) {
    emit(
      ActivitySettingsState(
        settings: ActivitySettings(
          movieType: movieType ?? state.settings.movieType,
        ),
      ),
    );
  }

  String getParameterValue(String code) {
    switch (code) {
      case DefaultActivitySettings.parameterCodeMovieType:
        return ActivitySettings.getMovieTypeValueFromUnsafe(state.settings.movieType);
    }

    return '';
  }

  void setParameterValue(String code, String value) {
    final String movieType = code == DefaultActivitySettings.parameterCodeMovieType
        ? value
        : getParameterValue(DefaultActivitySettings.parameterCodeMovieType);

    setValues(
      movieType: movieType,
    );
  }

  @override
  ActivitySettingsState? fromJson(Map<String, dynamic> json) {
    final String movieType = json[DefaultActivitySettings.parameterCodeMovieType] as String;

    return ActivitySettingsState(
      settings: ActivitySettings(
        movieType: movieType,
      ),
    );
  }

  @override
  Map<String, dynamic>? toJson(ActivitySettingsState state) {
    return <String, dynamic>{
      DefaultActivitySettings.parameterCodeMovieType: state.settings.movieType,
    };
  }
}
