import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:stopmotion/config/activity_page.dart';
import 'package:stopmotion/cubit/nav_cubit_pages.dart';

class BottomNavBar extends StatelessWidget {
  const BottomNavBar({super.key});

  @override
  Widget build(BuildContext context) {
    return Card(
      margin: const EdgeInsets.only(top: 1, right: 4, left: 4),
      elevation: 4,
      shadowColor: Theme.of(context).colorScheme.shadow,
      color: Theme.of(context).colorScheme.surfaceContainerHighest,
      shape: const RoundedRectangleBorder(
        borderRadius: BorderRadius.only(
          topLeft: Radius.circular(16),
          topRight: Radius.circular(16),
        ),
      ),
      child: BlocBuilder<NavCubitPage, int>(builder: (BuildContext context, int state) {
        final List<ActivityPageItem> pageItems = [
          ActivityPage.pageHome,
          ActivityPage.pageEditor,
          ActivityPage.pagePlayer,
        ];
        final List<BottomNavigationBarItem> items = pageItems.map((ActivityPageItem item) {
          return BottomNavigationBarItem(
            icon: item.icon,
            label: tr(item.code),
          );
        }).toList();

        return BottomNavigationBar(
          currentIndex: state,
          onTap: (int index) => context.read<NavCubitPage>().updateIndex(index),
          type: BottomNavigationBarType.fixed,
          elevation: 0,
          backgroundColor: Colors.transparent,
          selectedItemColor: Theme.of(context).colorScheme.primary,
          unselectedItemColor: Theme.of(context).textTheme.bodySmall!.color,
          items: items,
        );
      }),
    );
  }
}
